@@ -1,32 +1,5 @@
-///////////////////////////////////////////////////////////////////////////
-//
-// Copyright (c) DreamWorks Animation LLC
-//
-// All rights reserved. This software is distributed under the
-// Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
-//
-// Redistributions of source code must retain the above copyright
-// and license notice and the following restrictions and disclaimer.
-//
-// *     Neither the name of DreamWorks Animation nor the names of
-// its contributors may be used to endorse or promote products derived
-// from this software without specific prior written permission.
-//
-// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
-// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
-// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY INDIRECT, INCIDENTAL,
-// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-// IN NO EVENT SHALL THE COPYRIGHT HOLDERS' AND CONTRIBUTORS' AGGREGATE
-// LIABILITY FOR ALL CLAIMS REGARDLESS OF THEIR BASIS EXCEED US$250.00.
-//
-///////////////////////////////////////////////////////////////////////////
+// Copyright Contributors to the OpenVDB Project
+// SPDX-License-Identifier: MPL-2.0
 //
 /// @author Ken Museth
 ///
@@ -54,12 +27,13 @@ namespace util {
 inline Index32
 CountOn(Byte v)
 {
-    // Simple LUT:
-#ifndef _MSC_VER // Visual C++ doesn't guarantee thread-safe initialization of local statics
-    static
-#endif
-    /// @todo Move this table and others into, say, Util.cc
-    const Byte numBits[256] = {
+#if defined(OPENVDB_USE_SSE42) && defined(_MSC_VER)
+    return __popcnt16(v);
+#elif defined(OPENVDB_USE_SSE42) && (defined(__GNUC__) || defined(__clang__))
+    return __builtin_popcount(v);
+#else
+    // Software Implementation - Simple LUT
+    static const Byte numBits[256] = {
 #define COUNTONB2(n)  n,            n+1,            n+1,            n+2
 #define COUNTONB4(n)  COUNTONB2(n), COUNTONB2(n+1), COUNTONB2(n+1), COUNTONB2(n+2)
 #define COUNTONB6(n)  COUNTONB4(n), COUNTONB4(n+1), COUNTONB4(n+1), COUNTONB4(n+2)
@@ -69,14 +43,7 @@ CountOn(Byte v)
 #undef COUNTONB6
 #undef COUNTONB4
 #undef COUNTONB2
-
-    // Sequentially clear least significant bits
-    //Index32 c;
-    //for (c = 0; v; c++)  v &= v - 0x01U;
-    //return c;
-
-    // This version is only fast on CPUs with fast "%" and "*" operations
-    //return (v * UINT64_C(0x200040008001) & UINT64_C(0x111111111111111)) % 0xF;
+#endif
 }
 
 /// Return the number of off bits in the given 8-bit value.
@@ -98,10 +65,17 @@ inline Index32 CountOff(Index32 v) { return CountOn(~v); }
 inline Index32
 CountOn(Index64 v)
 {
+#if defined(OPENVDB_USE_SSE42) && defined(_MSC_VER) && defined(_M_X64)
+    v = __popcnt64(v);
+#elif defined(OPENVDB_USE_SSE42) && (defined(__GNUC__) || defined(__clang__))
+    v = __builtin_popcountll(v);
+#else
+    // Software Implementation
     v = v - ((v >> 1) & UINT64_C(0x5555555555555555));
     v = (v & UINT64_C(0x3333333333333333)) + ((v >> 2) & UINT64_C(0x3333333333333333));
-    return static_cast<Index32>(
-        (((v + (v >> 4)) & UINT64_C(0xF0F0F0F0F0F0F0F)) * UINT64_C(0x101010101010101)) >> 56);
+    v = (((v + (v >> 4)) & UINT64_C(0xF0F0F0F0F0F0F0F)) * UINT64_C(0x101010101010101)) >> 56;
+#endif
+    return static_cast<Index32>(v);
 }
 
 /// Return the number of off bits in the given 64-bit value.
@@ -112,11 +86,17 @@ inline Index32
 FindLowestOn(Byte v)
 {
     assert(v);
-#ifndef _MSC_VER // Visual C++ doesn't guarantee thread-safe initialization of local statics
-    static
-#endif
-    const Byte DeBruijn[8] = {0, 1, 6, 2, 7, 5, 4, 3};
+#if defined(OPENVDB_USE_SSE42) && defined(_MSC_VER)
+    unsigned long index;
+    _BitScanForward(&index, static_cast<Index32>(v));
+    return static_cast<Index32>(index);
+#elif defined(OPENVDB_USE_SSE42) && (defined(__GNUC__) || defined(__clang__))
+    return __builtin_ctz(v);
+#else
+    // Software Implementation
+    static const Byte DeBruijn[8] = {0, 1, 6, 2, 7, 5, 4, 3};
     return DeBruijn[Byte((v & -v) * 0x1DU) >> 5];
+#endif
 }
 
 /// Return the least significant on bit of the given 32-bit value.
@@ -125,10 +105,7 @@ FindLowestOn(Index32 v)
 {
     assert(v);
     //return ffs(v);
-#ifndef _MSC_VER // Visual C++ doesn't guarantee thread-safe initialization of local statics
-    static
-#endif
-    const Byte DeBruijn[32] = {
+    static const Byte DeBruijn[32] = {
         0, 1, 28, 2, 29, 14, 24, 3, 30, 22, 20, 15, 25, 17, 4, 8,
         31, 27, 13, 23, 21, 19, 16, 7, 26, 12, 18, 6, 11, 5, 10, 9
     };
@@ -140,27 +117,29 @@ inline Index32
 FindLowestOn(Index64 v)
 {
     assert(v);
-    //return ffsll(v);
-#ifndef _MSC_VER // Visual C++ doesn't guarantee thread-safe initialization of local statics
-    static
-#endif
-    const Byte DeBruijn[64] = {
+#if defined(OPENVDB_USE_SSE42) && defined(_MSC_VER)
+    unsigned long index;
+    _BitScanForward64(&index, v);
+    return static_cast<Index32>(index);
+#elif defined(OPENVDB_USE_SSE42) && (defined(__GNUC__) || defined(__clang__))
+    return static_cast<Index32>(__builtin_ctzll(v));
+#else
+    // Software Implementation
+    static const Byte DeBruijn[64] = {
         0,   1,  2, 53,  3,  7, 54, 27, 4,  38, 41,  8, 34, 55, 48, 28,
         62,  5, 39, 46, 44, 42, 22,  9, 24, 35, 59, 56, 49, 18, 29, 11,
         63, 52,  6, 26, 37, 40, 33, 47, 61, 45, 43, 21, 23, 58, 17, 10,
         51, 25, 36, 32, 60, 20, 57, 16, 50, 31, 19, 15, 30, 14, 13, 12,
     };
     return DeBruijn[Index64((v & -v) * UINT64_C(0x022FDD63CC95386D)) >> 58];
+#endif
 }
 
 /// Return the most significant on bit of the given 32-bit value.
 inline Index32
 FindHighestOn(Index32 v)
 {
-#ifndef _MSC_VER // Visual C++ doesn't guarantee thread-safe initialization of local statics
-    static
-#endif
-    const Byte DeBruijn[32] = {
+    static const Byte DeBruijn[32] = {
         0, 9, 1, 10, 13, 21, 2, 29, 11, 14, 16, 18, 22, 25, 3, 30,
         8, 12, 20, 28, 15, 17, 24, 7, 19, 27, 23, 6, 26, 5, 4, 31
     };
@@ -1434,7 +1413,3 @@ public:
 } // namespace openvdb
 
 #endif // OPENVDB_UTIL_NODEMASKS_HAS_BEEN_INCLUDED
-
-// Copyright (c) DreamWorks Animation LLC
-// All rights reserved. This software is distributed under the
-// Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
