@@ -1,32 +1,5 @@
-///////////////////////////////////////////////////////////////////////////
-//
-// Copyright (c) DreamWorks Animation LLC
-//
-// All rights reserved. This software is distributed under the
-// Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
-//
-// Redistributions of source code must retain the above copyright
-// and license notice and the following restrictions and disclaimer.
-//
-// *     Neither the name of DreamWorks Animation nor the names of
-// its contributors may be used to endorse or promote products derived
-// from this software without specific prior written permission.
-//
-// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
-// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
-// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY INDIRECT, INCIDENTAL,
-// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-// IN NO EVENT SHALL THE COPYRIGHT HOLDERS' AND CONTRIBUTORS' AGGREGATE
-// LIABILITY FOR ALL CLAIMS REGARDLESS OF THEIR BASIS EXCEED US$250.00.
-//
-///////////////////////////////////////////////////////////////////////////
+// Copyright Contributors to the OpenVDB Project
+// SPDX-License-Identifier: MPL-2.0
 
 /*
  * Copyright (c) Side Effects Software Inc.
@@ -2080,6 +2053,8 @@ GU_PrimVDB::createMetadataFromAttrsAdapter(
         switch (attrib->getStorageClass()) {
 
         case GA_STORECLASS_INT:
+            if (!tuple)
+                continue;
             switch (entries) {
             case 1:
                 meta_map.removeMeta(name);
@@ -2135,6 +2110,8 @@ GU_PrimVDB::createMetadataFromAttrsAdapter(
             break;
 
         case GA_STORECLASS_FLOAT:
+            if (!tuple)
+                continue;
             switch (entries) {
             case 1:
                 meta_map.removeMeta(name);
@@ -2183,9 +2160,9 @@ GU_PrimVDB::createMetadataFromAttrsAdapter(
             }
             break;
 
-        case GA_STORECLASS_STRING:
-            if (entries == 1) {
-                GA_ROHandleS handle(attrib);
+        case GA_STORECLASS_STRING: {
+            GA_ROHandleS handle(attrib);
+            if (entries == 1 && handle.isValid()) {
                 meta_map.removeMeta(name);
                 const char* str = handle.get(element);
                 if (!str) str = "";
@@ -2197,6 +2174,7 @@ GU_PrimVDB::createMetadataFromAttrsAdapter(
                 //    << it.name() << "\" (string tuples are not supported)";
             }
             break;
+        }
 
         case GA_STORECLASS_INVALID: break;
         case GA_STORECLASS_OTHER: break;
@@ -2221,7 +2199,3 @@ newGeometryPrim(GA_PrimitiveFactory *factory)
 #endif
 
 #endif // SESI_OPENVDB || SESI_OPENVDB_PRIM
-
-// Copyright (c) DreamWorks Animation LLC
-// All rights reserved. This software is distributed under the
-// Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
