@@ -1,32 +1,5 @@
-///////////////////////////////////////////////////////////////////////////
-//
-// Copyright (c) DreamWorks Animation LLC
-//
-// All rights reserved. This software is distributed under the
-// Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
-//
-// Redistributions of source code must retain the above copyright
-// and license notice and the following restrictions and disclaimer.
-//
-// *     Neither the name of DreamWorks Animation nor the names of
-// its contributors may be used to endorse or promote products derived
-// from this software without specific prior written permission.
-//
-// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
-// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
-// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY INDIRECT, INCIDENTAL,
-// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-// IN NO EVENT SHALL THE COPYRIGHT HOLDERS' AND CONTRIBUTORS' AGGREGATE
-// LIABILITY FOR ALL CLAIMS REGARDLESS OF THEIR BASIS EXCEED US$250.00.
-//
-///////////////////////////////////////////////////////////////////////////
+// Copyright Contributors to the OpenVDB Project
+// SPDX-License-Identifier: MPL-2.0
 //
 /// @file SOP_OpenVDB_Combine.cc
 ///
@@ -1050,11 +1023,7 @@ struct SOP_OpenVDB_Combine::CombineOp
             // For non-level set grids or if level set rebuild failed due to an unsupported
             // grid type, use the grid transformer tool to resample the source grid to match
             // the reference grid.
-#if OPENVDB_ABI_VERSION_NUMBER <= 3
-            dest = src.copy(openvdb::CP_NEW);
-#else
             dest = src.copyWithNewTree();
-#endif
             dest->setTransform(refXform.copy());
             using namespace openvdb;
             switch (order) {
@@ -1276,11 +1245,7 @@ struct SOP_OpenVDB_Combine::CombineOp
                 const Blend1<ValueT> comp(aMult, bMult);
                 ValueT bg;
                 comp(aGrid->background(), ZERO, bg);
-#if OPENVDB_ABI_VERSION_NUMBER <= 3
-                resultGrid = aGrid->copy(/*tree=*/openvdb::CP_NEW);
-#else
                 resultGrid = aGrid->copyWithNewTree();
-#endif
                 openvdb::tools::changeBackground(resultGrid->tree(), bg);
                 resultGrid->tree().combine2(aGrid->tree(), bGrid->tree(), comp, /*prune=*/false);
                 break;
@@ -1290,11 +1255,7 @@ struct SOP_OpenVDB_Combine::CombineOp
                 const Blend2<ValueT> comp(aMult, bMult);
                 ValueT bg;
                 comp(aGrid->background(), ZERO, bg);
-#if OPENVDB_ABI_VERSION_NUMBER <= 3
-                resultGrid = aGrid->copy(/*tree=*/openvdb::CP_NEW);
-#else
                 resultGrid = aGrid->copyWithNewTree();
-#endif
                 openvdb::tools::changeBackground(resultGrid->tree(), bg);
                 resultGrid->tree().combine2(aGrid->tree(), bGrid->tree(), comp, /*prune=*/false);
                 break;
@@ -1548,7 +1509,3 @@ SOP_OpenVDB_Combine::Cache::combineGrids(
     }
     return compOp.outGrid;
 }
-
-// Copyright (c) DreamWorks Animation LLC
-// All rights reserved. This software is distributed under the
-// Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
