@@ -1,32 +1,5 @@
-///////////////////////////////////////////////////////////////////////////
-//
-// Copyright (c) DreamWorks Animation LLC
-//
-// All rights reserved. This software is distributed under the
-// Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
-//
-// Redistributions of source code must retain the above copyright
-// and license notice and the following restrictions and disclaimer.
-//
-// *     Neither the name of DreamWorks Animation nor the names of
-// its contributors may be used to endorse or promote products derived
-// from this software without specific prior written permission.
-//
-// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
-// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
-// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY INDIRECT, INCIDENTAL,
-// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
-// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
-// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
-// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
-// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-// IN NO EVENT SHALL THE COPYRIGHT HOLDERS' AND CONTRIBUTORS' AGGREGATE
-// LIABILITY FOR ALL CLAIMS REGARDLESS OF THEIR BASIS EXCEED US$250.00.
-//
-///////////////////////////////////////////////////////////////////////////
+// Copyright Contributors to the OpenVDB Project
+// SPDX-License-Identifier: MPL-2.0
 //
 /// @file SOP_OpenVDB_Scatter.cc
 ///
@@ -77,6 +50,8 @@ public:
 
     class Cache: public SOP_VDBCacheOptions { OP_ERROR cookVDBSop(OP_Context&) override; };
 
+    void syncNodeVersion(const char* oldVersion, const char*, bool*) override;
+
 protected:
     bool updateParmsFlags() override;
     void resolveObsoleteParms(PRM_ParmList*) override;
@@ -186,6 +161,19 @@ newSopOperator(OP_OperatorTable* table)
             "For scalar-valued VDBs other than signed distance fields,"
             " use voxel values as local multipliers for point density."));
 
+    parms.add(hutil::ParmFactory(PRM_ORD, "poscompression", "Position Compression")
+        .setDefault(PRMoneDefaults)
+        .setChoiceListItems(PRM_CHOICELIST_SINGLE, {
+            "none",   "None",
+            "int16",  "16-bit Fixed Point",
+            "int8",   "8-bit Fixed Point"
+        })
+        .setTooltip("The position attribute compression setting.")
+        .setDocumentation(
+            "The position can be stored relative to the center of the voxel.\n"
+            "This means it does not require the full 32-bit float representation,\n"
+            "but can be quantized to a smaller fixed-point value."));
+
     parms.add(hutil::ParmFactory(PRM_STRING, "sdfdomain", "SDF Domain")
         .setChoiceListItems(PRM_CHOICELIST_SINGLE, {
             "interior",  "Interior",
@@ -264,6 +252,38 @@ and usage examples.\n");
 }
 
 
+void
+SOP_OpenVDB_Scatter::syncNodeVersion(const char* oldVersion, const char*, bool*)
+{
+    // Since VDB 7.0.0, position compression is now set to 16-bit fixed point
+    // by default. Detect if the VDB version that this node was created with
+    // was earlier than 7.0.0 and revert back to null compression if so to
+    // prevent potentially breaking older scenes.
+
+    // VDB version string prior to 6.2.0 - "17.5.204"
+    // VDB version string since 6.2.0 - "vdb6.2.0 houdini17.5.204"
+
+    openvdb::Name oldVersionStr(oldVersion);
+
+    bool disableCompression = false;
+    size_t spacePos = oldVersionStr.find_first_of(' ');
+    if (spacePos == std::string::npos) {
+        // no space in VDB versions prior to 6.2.0
+        disableCompression = true;
+    } else if (oldVersionStr.size() > 3 && oldVersionStr.substr(0,3) == "vdb") {
+        std::string vdbVersion = oldVersionStr.substr(3,spacePos-3);
+        // disable compression in VDB version 6.2.1 or earlier
+        if (UT_String::compareVersionString(vdbVersion.c_str(), "6.2.1") <= 0) {
+            disableCompression = true;
+        }
+    }
+
+    if (disableCompression) {
+        setInt("poscompression", 0, 0, 0);
+    }
+}
+
+
 void
 SOP_OpenVDB_Scatter::resolveObsoleteParms(PRM_ParmList* obsoleteParms)
 {
@@ -297,6 +317,7 @@ SOP_OpenVDB_Scatter::updateParmsFlags()
     changed |= setVisibleState("outputname", (1 == vdbpoints));
     changed |= setVisibleState("customname", (1 == vdbpoints));
     changed |= setVisibleState("cliptoisosurface", (1 == vdbpoints));
+    changed |= setVisibleState("poscompression", (1 == vdbpoints));
 
     changed |= enableParm("customname", (0 != evalInt("outputname", 0, time)));
     changed |= enableParm("sgroup", (1 == evalInt("dogroup", 0, time)));
@@ -492,8 +513,13 @@ private:
 
 struct BaseScatter
 {
-    using PositionArray =
-        openvdb::points::TypedAttributeArray<openvdb::Vec3f, openvdb::points::NullCodec>;
+    using NullCodec = openvdb::points::NullCodec;
+    using FixedCodec16 = openvdb::points::FixedPointCodec<false>;
+    using FixedCodec8 = openvdb::points::FixedPointCodec<true>;
+
+    using PositionArray = openvdb::points::TypedAttributeArray<openvdb::Vec3f, NullCodec>;
+    using PositionArray16 = openvdb::points::TypedAttributeArray<openvdb::Vec3f, FixedCodec16>;
+    using PositionArray8 = openvdb::points::TypedAttributeArray<openvdb::Vec3f, FixedCodec8>;
 
     BaseScatter(const unsigned int seed,
                 const float spread,
@@ -536,19 +562,34 @@ struct VDBUniformScatter : public BaseScatter
     VDBUniformScatter(const openvdb::Index64 count,
                       const unsigned int seed,
                       const float spread,
+                      const int compression,
                       hvdb::Interrupter* interrupter)
         : BaseScatter(seed, spread, interrupter)
         , mCount(count)
+        , mCompression(compression)
     {}
 
-    template <typename GridT>
-    inline void operator()(const GridT& grid)
+    template <typename PositionT, typename GridT>
+    inline void resolveCompression(const GridT& grid)
     {
         using namespace openvdb::points;
         using PointDataGridT =
             openvdb::Grid<typename TreeConverter<typename GridT::TreeType>::Type>;
-        mPoints = uniformPointScatter<GridT, std::mt19937, PositionArray, PointDataGridT,
-                hvdb::Interrupter>(grid, mCount, mSeed, mSpread, mInterrupter);
+        mPoints = openvdb::points::uniformPointScatter<
+            GridT, std::mt19937, PositionT, PointDataGridT, hvdb::Interrupter>(
+                grid, mCount, mSeed, mSpread, mInterrupter);
+    }
+
+    template <typename GridT>
+    inline void operator()(const GridT& grid)
+    {
+        if (mCompression == 1) {
+            this->resolveCompression<PositionArray16>(grid);
+        } else if (mCompression == 2) {
+            this->resolveCompression<PositionArray8>(grid);
+        } else {
+            this->resolveCompression<PositionArray>(grid);
+        }
     }
 
     void print(const std::string &name, std::ostream& os = std::cout) const
@@ -558,6 +599,7 @@ struct VDBUniformScatter : public BaseScatter
     }
 
     const openvdb::Index64 mCount;
+    const int mCompression;
 }; // VDBUniformScatter
 
 
@@ -566,21 +608,35 @@ struct VDBDenseUniformScatter : public BaseScatter
     VDBDenseUniformScatter(const float pointsPerVoxel,
                            const unsigned int seed,
                            const float spread,
+                           const int compression,
                            hvdb::Interrupter* interrupter)
         : BaseScatter(seed, spread, interrupter)
         , mPointsPerVoxel(pointsPerVoxel)
-        {}
+        , mCompression(compression)
+    {}
 
-    template <typename GridT>
-    inline void operator()(const GridT& grid)
+    template <typename PositionT, typename GridT>
+    inline void resolveCompression(const GridT& grid)
     {
         using namespace openvdb::points;
         using PointDataGridT =
             openvdb::Grid<typename TreeConverter<typename GridT::TreeType>::Type>;
-        mPoints = denseUniformPointScatter<GridT, std::mt19937, PositionArray, PointDataGridT,
+        mPoints = denseUniformPointScatter<GridT, std::mt19937, PositionT, PointDataGridT,
                 hvdb::Interrupter>(grid, mPointsPerVoxel, mSeed, mSpread, mInterrupter);
     }
 
+    template <typename GridT>
+    inline void operator()(const GridT& grid)
+    {
+        if (mCompression == 1) {
+            this->resolveCompression<PositionArray16>(grid);
+        } else if (mCompression == 2) {
+            this->resolveCompression<PositionArray8>(grid);
+        } else {
+            this->resolveCompression<PositionArray>(grid);
+        }
+    }
+
     void print(const std::string &name, std::ostream& os = std::cout) const
     {
         os << "Dense uniformly scattered ";
@@ -588,6 +644,7 @@ struct VDBDenseUniformScatter : public BaseScatter
     }
 
     const float mPointsPerVoxel;
+    const int mCompression;
 }; // VDBDenseUniformScatter
 
 
@@ -596,21 +653,35 @@ struct VDBNonUniformScatter : public BaseScatter
     VDBNonUniformScatter(const float pointsPerVoxel,
                       const unsigned int seed,
                       const float spread,
+                      const int compression,
                       hvdb::Interrupter* interrupter)
         : BaseScatter(seed, spread, interrupter)
         , mPointsPerVoxel(pointsPerVoxel)
+        , mCompression(compression)
     {}
 
-    template <typename GridT>
-    inline void operator()(const GridT& grid)
+    template <typename PositionT, typename GridT>
+    inline void resolveCompression(const GridT& grid)
     {
         using namespace openvdb::points;
         using PointDataGridT =
             openvdb::Grid<typename TreeConverter<typename GridT::TreeType>::Type>;
-        mPoints = nonUniformPointScatter<GridT, std::mt19937, PositionArray, PointDataGridT,
+        mPoints = nonUniformPointScatter<GridT, std::mt19937, PositionT, PointDataGridT,
                 hvdb::Interrupter>(grid, mPointsPerVoxel, mSeed, mSpread, mInterrupter);
     }
 
+    template <typename GridT>
+    inline void operator()(const GridT& grid)
+    {
+        if (mCompression == 1) {
+            this->resolveCompression<PositionArray16>(grid);
+        } else if (mCompression == 2) {
+            this->resolveCompression<PositionArray8>(grid);
+        } else {
+            this->resolveCompression<PositionArray>(grid);
+        }
+    }
+
     void print(const std::string &name, std::ostream& os = std::cout) const
     {
         os << "Non-uniformly scattered ";
@@ -618,6 +689,7 @@ struct VDBNonUniformScatter : public BaseScatter
     }
 
     const float mPointsPerVoxel;
+    const int mCompression;
 }; // VDBNonUniformScatter
 
 
@@ -786,6 +858,8 @@ SOP_OpenVDB_Scatter::Cache::cookVDBSop(OP_Context& context)
         const auto pmode = evalInt("pointmode", 0, time);
         const bool vdbPoints = evalInt("vdbpoints", 0, time) == 1;
         const bool clipPoints = vdbPoints && bool(evalInt("cliptoisosurface", 0, time));
+        const int posCompression = vdbPoints ?
+            static_cast<int>(evalInt("poscompression", 0, time)) : 0;
         const bool snapPointsToSurface =
             ((sdfdomain == "surface") && !openvdb::math::isApproxEqual(theSpread, 1.0f));
 
@@ -877,7 +951,7 @@ SOP_OpenVDB_Scatter::Cache::cookVDBSop(OP_Context& context)
 
             case 0: // fixed point count
                 if (vdbPoints) { // VDB points
-                    VDBUniformScatter scatter(pointCount, seed, spread, &boss);
+                    VDBUniformScatter scatter(pointCount, seed, spread, posCompression, &boss);
                     if (process(gridType, *grid, scatter, name))  {
                         postprocessVDBPoints(scatter, performCull);
                     }
@@ -891,8 +965,8 @@ SOP_OpenVDB_Scatter::Cache::cookVDBSop(OP_Context& context)
                 if (multiplyDensity && !isSignedDistance) { // local density
                     if (vdbPoints) { // VDB points
                         const auto dim = grid->transform().voxelSize();
-                        VDBNonUniformScatter scatter(
-                            static_cast<float>(density * dim.product()), seed, spread, &boss);
+                        VDBNonUniformScatter scatter(static_cast<float>(density * dim.product()),
+                            seed, spread, posCompression, &boss);
                         if (!UTvdbProcessTypedGridScalar(gridType, *grid, scatter)) {
                             throw std::runtime_error(
                                 "Only scalar grids support voxel scaling of density");
@@ -911,7 +985,8 @@ SOP_OpenVDB_Scatter::Cache::cookVDBSop(OP_Context& context)
                         const auto dim = grid->transform().voxelSize();
                         const auto totalPointCount = openvdb::Index64(
                             density * dim.product() * double(grid->activeVoxelCount()));
-                        VDBUniformScatter scatter(totalPointCount, seed, spread, &boss);
+                        VDBUniformScatter scatter(
+                            totalPointCount, seed, spread, posCompression, &boss);
                         if (process(gridType, *grid, scatter, name))  {
                             postprocessVDBPoints(scatter, performCull);
                         }
@@ -924,7 +999,8 @@ SOP_OpenVDB_Scatter::Cache::cookVDBSop(OP_Context& context)
 
             case 2: // points per voxel
                 if (vdbPoints) { // VDB points
-                    VDBDenseUniformScatter scatter(ptsPerVox, seed, spread, &boss);
+                    VDBDenseUniformScatter scatter(
+                        ptsPerVox, seed, spread, posCompression, &boss);
                     if (process(gridType, *grid, scatter, name))  {
                         postprocessVDBPoints(scatter, performCull);
                     }
@@ -987,7 +1063,3 @@ SOP_OpenVDB_Scatter::Cache::cookVDBSop(OP_Context& context)
     }
     return error();
 }
-
-// Copyright (c) DreamWorks Animation LLC
-// All rights reserved. This software is distributed under the
-// Mozilla Public License 2.0 ( http://www.mozilla.org/MPL/2.0/ )
